class EmailsController < ApplicationController
  model_data_store(Email)

  # POST /api/emails
  def create
    params = fix_info
    @model = Email.new(params)
    if @model.save
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  # PATCH /api/:id/email
  def update
    params = fix_info
    if @model.update(params)
      render json: @model
    else
      render json: @model.errors, status: :unprocessable_entity
    end
  end

  def send_test_email
    auth_settings = if test_email_params[:auth]
      password = test_email_params[:password]
      if password.blank? # since we don't send the saved password to the frontend when we load a saved email we may need to read it from the db
        email = Email.where(id: test_email_params[:id]).first
        password = email&.decrypted_password
      end
      {
        authentication: test_email_params[:auth_type]&.to_sym || :plain,
        user_name: test_email_params[:address],
        password: password
      }
    end
    Email.send_email(server: test_email_params[:server], port: test_email_params[:port], from: test_email_params[:address], to: test_email_params[:to], subject: "Rx-Suite Test Email", body: "If you have received this email, the Rx-Suite email settings are configured properly", auth_settings: auth_settings)
    render json: {sent: true}
  end

  private

  def fix_info
    params = model_params
    if params[:auth]
      params[:auth_type] = "plain" unless [nil, "plain", "login", "cram_md5"].include?(params[:auth_type])
    else
      params[:password] = ""
      params[:auth_type] = nil
    end
    if params[:password].empty?
      params.delete(:password)
    else
      config = Config.config
      encryption_key = config[:encryption_key]
      params[:password] = AES.encrypt(params[:password], encryption_key)
    end
    if params[:is_system_default]
      Email.where(is_system_default: true).update(is_system_default: false)
    end
    @model&.reload
    params
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def model_params
    params.fetch(:email).permit(:address, :password, :server, :port, :is_system_default, :auth, :auth_type)
  end

  def test_email_params
    params.permit(:to, :address, :password, :server, :port, :auth, :id, :auth_type)
  end
end
