class RolesController < ApplicationController
  model_data_store(Role)
  protect_with(nil, nil, [RxModule::Authorization.verb("create", "Create", :create_with_rules), RxModule::Authorization.verb("update", "Update", :update_with_rules)])

  def create_with_rules
    role_params = params.require(:roleModel).permit(:name)
    permission_params = params.permit(rolePermissions: [:component_permission_id, :permitted])

    role_permissions = permission_params[:rolePermissions].map do |rp|
      {
        component_permission_id: rp[:component_permission_id],
        permitted: rp[:permitted]
      }
    end

    role = Role.new(name: role_params[:name])
    permissions = role.role_permissions.build(role_permissions)

    if role.save
      render json: {role: role, permissions: permissions}, status: :ok
    else
      render json: role.errors, status: :unprocessable_entity
    end
  end

  def update_with_rules
    role_params = params.require(:roleModel).permit(:name, :id)
    permission_params = params.permit(rolePermissions: [:component_permission_id, :permitted])

    role = Role.find(role_params[:id])
    role.name = role_params[:name]

    permissions = []
    RolePermission.transaction do
      permissions = permission_params[:rolePermissions].map do |rp|
        permission = role.role_permissions.find_or_initialize_by(component_permission_id: rp[:component_permission_id])
        permission.permitted = rp[:permitted]
        permission.save
      end
    end

    if role.save
      render json: {role: role, permissions: permissions}, status: :ok
    else
      render json: role.errors, status: :unprocessable_entity
    end
  end

  private

  # Use callbacks to share common setup or constraints between actions.
  def set_target
    @model = if params[:user_id]
      User.find(params[:user_id]).role
    else
      Role.find(params[:id])
    end
  end

  # Never trust parameters from the scary internet, only allow the white list through.
  def model_params
    params.require(:role).permit(:name)
  end
end
