import * as React from "react";
import {observer} from "mobx-react-lite";
import {SelectField} from "@rx-suite/ui";
import {t} from "@lingui/macro";
import {Schedule, ScheduleRecurrenceWeekdayNumeric, ShiftModel} from "../../../stores/ShiftStore";
import {runInAction} from "mobx";
import {Grid} from "@material-ui/core";

const dayOptions = [
    {label: t`First`, value: 1},
    {label: t`Second`, value: 2},
    {label: t`Third`, value: 3},
    {label: t`Fourth`, value: 4},
    {label: t`Fifth`, value: 5},
    {label: t`Last`, value: -1},
];


const mdayOptions = [
    ...Array.from(Array(31).keys()).map(i => ({
        label: (i + 1).toString(), value: (i + 1)
    })),
    {label: t`Last`, value: -1}
];
export const MonthlyOptions: React.FunctionComponent<{ shift: ShiftModel, schedule: Schedule, scheduleIndex: number }> = observer(({
                                                                                                                                       shift,
                                                                                                                                       schedule,
                                                                                                                                       scheduleIndex
                                                                                                                                   }) => {
    const [mode, setMode] = React.useState('day_of_week');
    const day = schedule.recurrence_rule.day || {} as {
        [day in ScheduleRecurrenceWeekdayNumeric]?: number[]
    };
    const mday = schedule.recurrence_rule.mday || [] as number[];
    const handleModeChange = React.useCallback((name, value) => {
        setMode(value);
        // since the resulting days are the intersection of each rule (not the union) we need to clear old values that would give unexpected results
        runInAction(() => {
            if (value === 'day_of_week') {
                shift.viewModel.shift_schedules = [...shift.viewModel.shift_schedules.slice(0, scheduleIndex),
                    {
                        ...shift.viewModel.shift_schedules[scheduleIndex],
                        recurrence_rule: {
                            every: shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule.every,
                            interval: shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule.interval,
                            day: {}
                        }
                    },
                    ...shift.viewModel.shift_schedules.slice(scheduleIndex + 1)];
            } else if (value === 'day_of_month') {
                shift.viewModel.shift_schedules = [...shift.viewModel.shift_schedules.slice(0, scheduleIndex),
                    {
                        ...shift.viewModel.shift_schedules[scheduleIndex],
                        recurrence_rule: {
                            every: shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule.every,
                            interval: shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule.interval,
                            mday: []
                        }
                    },
                    ...shift.viewModel.shift_schedules.slice(scheduleIndex + 1)];
            }
        });
    }, [shift, schedule, scheduleIndex, setMode]);
    const handleDaysChange = React.useCallback((name, value) => {
        runInAction(() => {
            shift.viewModel.shift_schedules = [...shift.viewModel.shift_schedules.slice(0, scheduleIndex),
                {
                    ...shift.viewModel.shift_schedules[scheduleIndex],
                    recurrence_rule: {
                        ...shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule,
                        day: {
                            ...(shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule.day || {}),
                            [name]: value.sort()
                        }
                    }
                },
                ...shift.viewModel.shift_schedules.slice(scheduleIndex + 1)];
        });
    }, [shift, schedule, scheduleIndex, day]);
    const handleMDayChange = React.useCallback((name, value) => {
        runInAction(() => {
            shift.viewModel.shift_schedules = [...shift.viewModel.shift_schedules.slice(0, scheduleIndex),
                {
                    ...shift.viewModel.shift_schedules[scheduleIndex],
                    recurrence_rule: {
                        ...shift.viewModel.shift_schedules[scheduleIndex].recurrence_rule,
                        mday: value.sort((a: number, b: number) => a - b)
                    }
                },
                ...shift.viewModel.shift_schedules.slice(scheduleIndex + 1)];
        });
    }, [shift, schedule, scheduleIndex, mday]);
    return (
        <div>
            <SelectField label={t`Repetition Type`} onChange={handleModeChange} value={mode} options={[
                {label: t`By Day of Week`, value: 'day_of_week'},
                {label: t`By Day of Month`, value: 'day_of_month'},
            ]}/>
            {(mode === 'day_of_month') &&
            <SelectField label={t`Date`} onChange={handleMDayChange} value={mday} options={mdayOptions} clearable
                         multiple/>}
            {(mode === 'day_of_week') && <Grid container spacing={2}>
                <Grid item xs>
                    <SelectField label={t`Sunday`} name={'0'}
                                 value={day['0'] || []}
                                 options={dayOptions}
                                 onChange={handleDaysChange}
                                 clearable multiple/>
                </Grid>
                <Grid item xs>
                    <SelectField label={t`Monday`} name={'1'}
                                 value={day['1'] || []}
                                 options={dayOptions}
                                 onChange={handleDaysChange}
                                 clearable multiple/>
                </Grid>
                <Grid item xs>
                    <SelectField label={t`Tuesday`} name={'2'}
                                 value={day['2'] || []}
                                 options={dayOptions}
                                 onChange={handleDaysChange}
                                 clearable multiple/>
                </Grid>
                <Grid item xs>
                    <SelectField label={t`Wednesday`} name={'3'}
                                 value={day['3'] || []}
                                 options={dayOptions}
                                 onChange={handleDaysChange}
                                 clearable multiple/>
                </Grid>
                <Grid item xs>
                    <SelectField label={t`Thursday`} name={'4'}
                                 value={day['4'] || []}
                                 options={dayOptions}
                                 onChange={handleDaysChange}
                                 clearable multiple/>
                </Grid>
                <Grid item xs>
                    <SelectField label={t`Friday`} name={'5'}
                                 value={day['5'] || []}
                                 options={dayOptions}
                                 onChange={handleDaysChange}
                                 clearable multiple/>
                </Grid>
                <Grid item xs>
                    <SelectField label={t`Saturday`} name={'6'}
                                 value={day['6'] || []}
                                 options={dayOptions}
                                 onChange={handleDaysChange}
                                 clearable multiple/>
                </Grid>
            </Grid>}
        </div>
    );
});