import * as React from "react";
import {observer} from "mobx-react-lite";
import {FormProps, ModelCheckbox, ModelForm, ModelInput, ModelSelect, PaddedPaper} from "@rx-suite/ui/build";
import {TextField, Typography} from "@material-ui/core";
import {t} from "@lingui/macro";
import {EmailModel} from "../../stores/EmailStore";
import {SendTestEmailButton} from "../../components/emails/SendTestEmailButton";

export const EmailForm: React.FunctionComponent<FormProps> = observer(({model, readOnly}) => {
        React.useEffect(() => {
            if (model && model.isNew && !model.store.models.length) {
                model.nestedAssignment('is_system_default', true);
            }
        }, [model, model.store.models.length]);
        return (
            <PaddedPaper>
                <Typography variant={'h4'}>{t`Email Info`}</Typography>
                <ModelForm model={model} readOnly={readOnly} suppressImportExport
                           postFormActions={<SendTestEmailButton email={model as EmailModel}/>}>
                    {/*capture the password auto-fill, since many browsers ignore autocomplete='off' on password fields*/}
                    {model.viewModel.auth &&
                    <TextField value={''} name={"password-dummy"} type={"password"} autoComplete={"current-password"}
                               disabled
                               style={{left: -9999, height: 0}}/>}
                    <ModelInput name={"address"}/>
                    <ModelInput name={"server"}/>
                    <ModelInput name={"port"}/>
                    <ModelCheckbox name={"auth"}/>
                    {model.viewModel.auth && <>
                        <ModelInput name={"password"} type={"password"} autoComplete={"new-password"}/>
                        <ModelSelect name={"auth_type"} options={[
                            {label: t`Plain`, value: 'plain'},
                            {label: t`Login`, value: 'login'},
                            {label: t`CRAM-MD5`, value: 'cram_md5'}
                        ]}/>
                    </>}
                    <ModelCheckbox name={"is_system_default"}/>
                    <br/>
                </ModelForm>
            </PaddedPaper>)
    }
);