import {attribute, DataStore, Model} from '@rx-suite/data';
import * as yup from 'yup';
import {t} from "@lingui/macro";
import {model} from "@rx-suite/data/build";

@model({
    transportLayer: '/api/licence_info',
    singleton: true,
    eager: true,
    permissionTarget: "licence_info"
})
export class LicenceInfoModel extends Model {
    @attribute({
        label: t`Licence Code`,
        description: t`This code determines what features you are entitled to use`,
        validation: yup.string().nullable().required(t`Licence Code is a required field`)
    })
    licence_code?: string | null = null;

    @attribute({
        label: t`Last Attempted Licence Check`,
        description: t`The last time the licence server was attempted to be contacted`,
    })
    last_check_attempt?: Date | null = new Date();

    @attribute({
        label: t`Last Successful Licence Check`,
        description: t`The last time the licence server has successfully contacted`,
    })
    last_successful_check?: Date | null = new Date();

    @attribute({
        label: t`Last Licence Check Error`,
        description: t`The most recent error encountered contacting the licence server`,
    })
    last_check_error?: string | null = null;
}

export const LicenceInfoStore = LicenceInfoModel.store as unknown as DataStore<LicenceInfoModel>;
