# == Schema Information
#
# Table name: emails
#
#  id                :bigint           not null, primary key
#  address           :string
#  auth              :boolean
#  auth_type         :string
#  is_system_default :boolean
#  password          :string
#  port              :integer
#  server            :string
#  created_at        :datetime         not null
#  updated_at        :datetime         not null
#
class Email < ApplicationRecord
  has_many :components

  class << self
    def send_email(server:, port:, from:, to:, subject:, body:, auth_settings: nil, attachments: nil, sync: true)
      smtp_settings = {
        address: server,
        port: port
      }
      if auth_settings
        smtp_settings.merge!(auth_settings)
      else
        smtp_settings[:enable_starttls_auto] = false
      end
      RxMailer.send_email(smtp_settings, from, to, subject, body, attachments).send(sync ? :deliver_now : :deliver_later)
    end
  end

  def send_email(to_address, subject_line, body, attachments = nil, sync = true)
    Email.send_email(server: server, port: port, from: address, to: to_address, subject: subject_line, body: body, auth_settings: auth_settings, attachments: attachments, sync: sync)
  end

  def send_email_async(to_address, subject_line, body, attachments = nil)
    send_email(to_address, subject_line, body, attachments, false)
  end

  def send_email_sync(to_address, subject_line, body, attachments = nil)
    send_email(to_address, subject_line, body, attachments, true)
  end

  def auth_settings
    if auth
      {
        authentication: auth_type&.to_sym || :plain,
        user_name: address,
        password: decrypted_password
      }
    else
      nil
    end
  end

  def decrypted_password
    encryption_key = Config.config[:encryption_key]
    AES.decrypt(password, encryption_key)
  end

  def to_json(*args)
    render_jbuilder_partial
  rescue
    super(*args)
  end
end
